import { Component, ElementRef, EventEmitter, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';

const ngxEditorConfig = {
    editable: true,
    spellcheck: true,
    translate: 'yes',
    placeholder: 'Enter text here...',
    toolbar: {
        text: ['fontFamily', 'fontSize', 'bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
        align: ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
        action: ['cut', 'copy', 'paste', 'delete', 'removeFormat', 'undo', 'redo'],
        insert: ['image', 'paragraph', 'blockquote', 'removeBlockquote', 'html', 'horizontalLine', 'orderedList', 'unorderedList'],
        extras: ['code', 'fullscreen', 'print']
    }
};

class NgxEditorComponent {
    /**
     * @param {?} element
     */
    constructor(element) {
        this.element = element;
        this.htmlChange = new EventEmitter();
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set config(value) {
        for (const /** @type {?} */ i in ngxEditorConfig) {
            if (!value.hasOwnProperty(i)) {
                value[i] = ngxEditorConfig[i];
            }
        }
        this._config = value;
    }
    /**
     * @return {?}
     */
    get config() {
        return this._config || ngxEditorConfig;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    set html(value) {
        this._html = value;
    }
    /**
     * @return {?}
     */
    get html() {
        return this._html;
    }
    /**
     * @param {?} value
     * @return {?}
     */
    htmlContentChange(value) {
        if (value === '<br>') {
            this.htmlChange.emit('');
        }
        else {
            this.htmlChange.emit(value);
        }
    }
    /**
     * @param {?} commandName
     * @return {?}
     */
    executeCommand(commandName) {
        const /** @type {?} */ isExecuted = document.execCommand(commandName, false, null);
    }
    /**
     * @return {?}
     */
    blockQuote() {
        document.execCommand('formatBlock', false, '<blockquote>');
    }
    /**
     * @return {?}
     */
    removeQuote() {
        document.execCommand('formatBlock', false, 'div');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.spellcheck === false) {
            this.config['spellcheck'] = false;
        }
        if (this.editable === false) {
            this.config['editable'] = false;
        }
        this.element.nativeElement.getElementsByClassName('textarea')[0].innerHTML = this.html || '';
    }
}
NgxEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ngx-editor',
                template: `
    <div class="ngx-editor" id="ngxEditor">
      <div class="toolbar responsive">
        <div class="set">
          <button (click)="executeCommand('bold')" title="Bold"><i class="fa fa-bold" aria-hidden="true"></i></button>
          <button (click)="executeCommand('italic')" title="Italic"><i class="fa fa-italic" aria-hidden="true"></i></button>
          <button (click)="executeCommand('underline')" title="Underline"><i class="fa fa-underline" aria-hidden="true"></i></button>
          <button (click)="executeCommand('strikeThrough')" title="Strikethrough"><i class="fa fa-strikethrough" aria-hidden="true"></i></button>
          <button (click)="executeCommand('superscript')" title="Superscript"><i class="fa fa-superscript" aria-hidden="true"></i></button>
          <button (click)="executeCommand('subscript')" title="Subscript"><i class="fa fa-subscript" aria-hidden="true"></i></button>
        </div>
        <div class="set no-sm-device">
          <button (click)="executeCommand('justifyLeft')" title="Justify Left"><i class="fa fa-align-left" aria-hidden="true"></i></button>
          <button (click)="executeCommand('justifyCenter')" title="Justify Center"><i class="fa fa-align-center" aria-hidden="true"></i></button>
          <button (click)="executeCommand('justifyRight')" title="Justify Right"><i class="fa fa-align-right" aria-hidden="true"></i></button>
          <button (click)="executeCommand('justifyFull')" title="Justify"><i class="fa fa-align-justify" aria-hidden="true"></i></button>
          <button (click)="executeCommand('indent')" title="Indent"><i class="fa fa-indent" aria-hidden="true"></i></button>
          <button (click)="executeCommand('outdent')" title="Outdent"><i class="fa fa-outdent" aria-hidden="true"></i></button>
        </div>
        <div class="set no-md-device">
          <button (click)="executeCommand('cut')" title="Cut"><i class="fa fa-scissors" aria-hidden="true"></i></button>
          <button (click)="executeCommand('copy')" title="Copy"><i class="fa fa-files-o" aria-hidden="true"></i></button>
          <button (click)="executeCommand('delete')" title="Delete"><i class="fa fa-trash" aria-hidden="true"></i></button>
          <button (click)="executeCommand('removeFormat')" title="Clear Formatting"><i class="fa fa-eraser" aria-hidden="true"></i></button>
          <button (click)="executeCommand('undo')" title="Undo"><i class="fa fa-undo" aria-hidden="true"></i></button>
          <button (click)="executeCommand('redo')" title="Redo"><i class="fa fa-repeat" aria-hidden="true"></i></button>
        </div>
        <div class="set no-md-device">
          <button (click)="executeCommand('insertParagraph')" title="Paragraph"><i class="fa fa-paragraph" aria-hidden="true"></i></button>
          <button (click)="blockQuote()" title="Blockquote"><i class="fa fa-quote-left" aria-hidden="true"></i></button>
          <button (click)="removeQuote()" title="Remove Blockquote"><i class="fa fa-quote-right" aria-hidden="true"></i></button>
          <button (click)="executeCommand('insertHorizontalRule')" title="Horizontal Line"><i class="fa fa-minus" aria-hidden="true"></i></button>
          <button (click)="executeCommand('insertUnorderedList')" title="Unodered List"><i class="fa fa-list-ul" aria-hidden="true"></i></button>
          <button (click)="executeCommand('insertOrderedList')" title="Ordered List"><i class="fa fa-list-ol" aria-hidden="true"></i></button>
        </div>
      </div>
      <div class="textarea" [attr.contenteditable]="editable || config['editable']" [attr.placeholder]="placeholder || config['placeholder']"
        (input)="html = $event.target.innerHTML; htmlContentChange($event.target.innerHTML)" [attr.translate]="translate || config['translate']"
        [attr.spellcheck]="config['spellcheck']"></div>
    </div>
  `,
                styles: [`
    /*
     * media screen break points
     */
    /*
     * editor styles
     */
    .ngx-editor {
      position: relative; }
      .ngx-editor ::ng-deep [contenteditable=true]:empty:before {
        content: attr(placeholder);
        display: block; }
      .ngx-editor .toolbar {
        background-color: #f5f5f5;
        border-bottom: 1px solid #ddd;
        font-size: 0.8rem;
        padding: 0.2rem;
        border: 1px solid #ddd; }
        .ngx-editor .toolbar .set {
          display: inline-block;
          border: 1px solid #ddd;
          border-radius: 5px;
          background-color: white; }
          .ngx-editor .toolbar .set button {
            background-color: #f5f5f5;
            background-color: transparent;
            border: 0;
            padding: 0.4rem;
            min-width: 2.5rem;
            float: left;
            border-right: 1px solid #ddd; }
            .ngx-editor .toolbar .set button:hover {
              cursor: pointer;
              background-color: #e3e3e3;
              -webkit-transition: 0.5s ease;
              transition: 0.5s ease; }
            .ngx-editor .toolbar .set button:focus, .ngx-editor .toolbar .set button.focus {
              outline: 0; }
            .ngx-editor .toolbar .set button:last-child {
              border-right: transparent; }
        @media screen and (max-width: 992px) {
          .ngx-editor .toolbar.responsive .no-lg-device {
            display: none; } }
        @media screen and (max-width: 768px) {
          .ngx-editor .toolbar.responsive .no-md-device {
            display: none; } }
        @media screen and (max-width: 480px) {
          .ngx-editor .toolbar.responsive .no-sm-device {
            display: none; } }
        @media screen and (max-width: 320px) {
          .ngx-editor .toolbar.responsive .no-xs-device {
            display: none; } }
      .ngx-editor .textarea {
        min-height: 5rem;
        padding: 0.5rem 0.8rem 1rem 0.8rem;
        border: 1px solid #ddd;
        border-top: transparent;
        resize: vertical;
        overflow: auto;
        background-color: #fff; }
        .ngx-editor .textarea:focus, .ngx-editor .textarea.focus {
          outline: 0; }
        .ngx-editor .textarea ::ng-deep blockquote {
          margin-left: 1rem;
          border-left: 0.2em solid #dfe2e5;
          padding-left: 0.5rem; }
        .ngx-editor .textarea .grabber {
          content: '';
          position: absolute;
          bottom: 0;
          margin-left: -0.8rem;
          cursor: s-resize;
          height: 9px;
          width: 100%;
          border-top: 1px solid #f1f1f1;
          overflow: hidden;
          background-color: #eff0f1;
          background-image: url("../../assets/grabber/grabber.png");
          background-image: url("../../assets/grabber/grabber.svg"), none;
          background-size: initial;
          background-repeat: no-repeat;
          background-position: center; }

    .hide {
      display: none !important; }
  `]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorComponent.ctorParameters = () => [
    { type: ElementRef, },
];
NgxEditorComponent.propDecorators = {
    'htmlChange': [{ type: Output },],
    'config': [{ type: Input },],
    'html': [{ type: Input },],
    'editable': [{ type: Input },],
    'spellcheck': [{ type: Input },],
    'placeholder': [{ type: Input },],
    'translate': [{ type: Input },],
};

class NgxEditorModule {
}
NgxEditorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    NgxEditorComponent
                ],
                exports: [
                    NgxEditorComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxEditorModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { NgxEditorModule, NgxEditorComponent as ɵa };
//# sourceMappingURL=ngx-editor.js.map
